@@ -9,6 +9,7 @@ class Densifier(AutoSklearnPreprocessingAlgorithm):
         pass
 
     def fit(self, X, y=None):
+        self.fitted_ = True
         return self
 
     def transform(self, X):
@@ -26,6 +27,7 @@ class Densifier(AutoSklearnPreprocessingAlgorithm):
                 'handles_classification': True,
                 'handles_multiclass': True,
                 'handles_multilabel': True,
+                'handles_multioutput': True,
                 'is_deterministic': True,
                 'input': (SPARSE, UNSIGNED_DATA),
                 'output': (DENSE, INPUT)}
