@@ -8,10 +8,10 @@ class NoPreprocessing(AutoSklearnPreprocessingAlgorithm):
 
     def __init__(self, random_state):
         """ This preprocessors does not change the data """
-        self.preprocessor = None
 
     def fit(self, X, Y=None):
-        self.preprocessor = 0
+        self.preprocessor = 'passthrough'
+        self.fitted_ = True
         return self
 
     def transform(self, X):
@@ -27,6 +27,7 @@ class NoPreprocessing(AutoSklearnPreprocessingAlgorithm):
                 'handles_classification': True,
                 'handles_multiclass': True,
                 'handles_multilabel': True,
+                'handles_multioutput': True,
                 'is_deterministic': True,
                 'input': (SPARSE, DENSE, UNSIGNED_DATA),
                 'output': (INPUT,)}
