@@ -4,8 +4,9 @@ BINARY_CLASSIFICATION = 1
 MULTICLASS_CLASSIFICATION = 2
 MULTILABEL_CLASSIFICATION = 3
 REGRESSION = 4
+MULTIOUTPUT_REGRESSION = 5
 
-REGRESSION_TASKS = [REGRESSION]
+REGRESSION_TASKS = [REGRESSION, MULTIOUTPUT_REGRESSION]
 CLASSIFICATION_TASKS = [BINARY_CLASSIFICATION, MULTICLASS_CLASSIFICATION,
                         MULTILABEL_CLASSIFICATION]
 
@@ -15,21 +16,23 @@ TASK_TYPES_TO_STRING = \
     {BINARY_CLASSIFICATION: "binary.classification",
      MULTICLASS_CLASSIFICATION: "multiclass.classification",
      MULTILABEL_CLASSIFICATION: "multilabel.classification",
-     REGRESSION: "regression"}
+     REGRESSION: "regression",
+     MULTIOUTPUT_REGRESSION: "multioutput.regression"}
 
 STRING_TO_TASK_TYPES = \
     {"binary.classification": BINARY_CLASSIFICATION,
      "multiclass.classification": MULTICLASS_CLASSIFICATION,
      "multilabel.classification": MULTILABEL_CLASSIFICATION,
-     "regression": REGRESSION}
+     "regression": REGRESSION,
+     "multioutput.regression": MULTIOUTPUT_REGRESSION}
 
-DENSE = 5
-SPARSE = 6
-PREDICTIONS = 7
-INPUT = 8
+DENSE = 6
+SPARSE = 7
+PREDICTIONS = 8
+INPUT = 9
 
-SIGNED_DATA = 9
-UNSIGNED_DATA = 10
+SIGNED_DATA = 10
+UNSIGNED_DATA = 11
 
 DATASET_PROPERTIES_TO_STRING = \
     {DENSE:         'dense',
